.. _pythondemos:

Python Demos
============

A number of examples illustrating the use of the EveryBeam Python bindings can be found below.
:ref:`oskardemopointresponse` and :ref:`lofardemogriddedresponse` mainly illustrate basic functionality of the Python
bindings, whereas :ref:`lofardemolobes` demonstrates how the Python bindings can be used to generate an all-sky image for
the element and station response for a LOFAR observation.

.. toctree::
   :maxdepth: 1

   demos/oskar-point-response
   demos/lofar-grid-response
   demos/lofar-lobes
   demos/lofar-array-factor
